Commands

Enum Commands 

pub(crate) enum Commands {
    Add {
        name: String,
        path: PathBuf,
    },
    List,
    Remove {
        name: String,
    },
    Env {
        command: EnvCommands,
    },
    Worktree {
        vcs: Option<String>,
        command: WorktreeCommands,
    },
    Start {
        project: String,
        name: String,
        vcs: Option<String>,
    },
    InitMise,
}

Variants



Add

Register an existing git repo

Fields

name: String

Short name to identify this project in grove commands

path: PathBuf

Path to the git or jj repository root (must contain .git or .jj)



List

Show all registered projects



Remove

Unregister a project (doesn’t delete files)

Fields

name: String

Name of the project to unregister



Env

Manage environment variables

Fields

command: EnvCommands


Worktree

Manage git/jj worktrees

Fields

vcs: Option<String>

Force a specific VCS backend (e.g., “git”) instead of auto-detection



Start

Create a worktree, run hooks, and open editor

Fields

project: String

Name of the registered project

name: String

Name for the new worktree (alphanumeric, hyphens, underscores only)

vcs: Option<String>

Force a specific VCS backend (e.g., “git”) instead of auto-detection



InitMise

Install grove plugin for mise