EnvCommands

Enum EnvCommands 

pub(crate) enum EnvCommands {
    Set {
        project_or_pair: String,
        pair: Option<String>,
    },
    List {
        project: Option<String>,
    },
    Unset {
        project_or_key: String,
        key: Option<String>,
    },
    Export {
        json: bool,
        path: PathBuf,
    },
}

Variants



Set

Set an environment variable

Fields

project_or_pair: String

Project name or KEY=value pair (auto-detects project from cwd if KEY=value)

pair: Option<String>

KEY=value pair (when first argument is a project name)



List

Show all environment variables

Fields

project: Option<String>

Project name or project/worktree (auto-detects from cwd if omitted)



Unset

Remove an environment variable

Fields

project_or_key: String

Project name or env var key (auto-detects project from cwd if only one arg)

key: Option<String>

Env var key (when first argument is a project name)



Export

Output environment variables for the project containing a path

Fields

json: bool

Output as a JSON object instead of KEY=value lines

path: PathBuf

Directory path to resolve the project and worktree from