LeftOf

Struct LeftOf 

pub struct LeftOf<L>(pub L);
A Wrapper for other locators what will find the segment to the left of the previous locator. So, LeftOf(5..8) is equivalent to 0..5.

Tuple Fields

0: L